@@ -1,4 +1,4 @@
-/* xscreensaver, Copyright (c) 1993-1998 by Jamie Zawinski <jwz@netscape.com>
+/* xscreensaver, Copyright (c) 1993-2000 by Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
  * documentation for any purpose is hereby granted without fee, provided that
@@ -23,5 +23,8 @@ extern Visual *find_similar_visual (Screen *, Visual *old);
 extern void describe_visual (FILE *f, Screen *, Visual *, Bool private_cmap_p);
 extern Visual *get_overlay_visual (Screen *, unsigned long *pixel_return);
 extern Bool has_writable_cells (Screen *screen, Visual *visual);
+extern Visual *id_to_visual (Screen *screen, int id);
+
+Visual *get_gl_visual (Screen *screen);
 
 #endif /* __VISUAL_H__ */
